# MyST-NB

[![Github-CI][github-ci]][github-link]
[![Coverage Status][codecov-badge]][codecov-link]
[![Documentation Status][rtd-badge]][rtd-link]
[![PyPI][pypi-badge]][pypi-link]
[![Conda Version][conda-badge]][conda-link]

A collection of tools for working with Jupyter Notebooks in Sphinx.

The primary tool this package provides is a Sphinx parser for `ipynb` files.
This allows you to directly convert Jupyter Notebooks into Sphinx documents.
It relies heavily on the [`MyST` parser](https://github.com/executablebooks/myst-parser).

For more information, [see the MyST-NB documentation](https://myst-nb.readthedocs.io/en/latest/)

## Contributing

We welcome all contributions!
See the [Contributing Guide](https://myst-nb.readthedocs.io/en/latest/reference/contributing.html) for more details.

[github-ci]: https://github.com/executablebooks/MyST-NB/workflows/continuous-integration/badge.svg?branch=master
[github-link]: https://github.com/executablebooks/MyST-NB
[rtd-badge]: https://readthedocs.org/projects/myst-nb/badge/?version=latest
[rtd-link]: https://myst-nb.readthedocs.io/en/latest/?badge=latest
[codecov-badge]: https://codecov.io/gh/executablebooks/MyST-NB/branch/master/graph/badge.svg
[codecov-link]: https://codecov.io/gh/executablebooks/MyST-NB
[pypi-badge]: https://img.shields.io/pypi/v/myst-nb.svg
[pypi-link]: https://pypi.org/project/myst-nb
[conda-badge]: https://img.shields.io/conda/vn/conda-forge/myst-nb.svg
[conda-link]: https://anaconda.org/conda-forge/myst-nb
